@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 colors = {
     "bg0": " #fbf1c7",
     "bg1": " #ebdbb2",
@@ -24,6 +26,9 @@ colors = {
     "blue2": " #076678",
     "purple": " #b16286",
     "purple2": " #8f3f71",
+    "redis": "#D82C20",
+    "mongodb": "#00ED64",
+    "memcached": "",
 }
 
 html_theme = "furo"
@@ -42,6 +47,9 @@ html_theme_options = {
         "color-aqua": colors["aqua2"],
         "color-blue": colors["blue2"],
         "color-purple": colors["purple2"],
+        "color-redis": colors["redis"],
+        "color-mongodb": colors["mongodb"],
+        "color-memcached": colors["memcached"],
     },
     "dark_css_variables": {
         "color-brand-primary": colors["purple"],
@@ -61,6 +69,9 @@ html_theme_options = {
         "color-aqua": colors["aqua"],
         "color-blue": colors["blue"],
         "color-purple": colors["purple"],
+        "color-redis": colors["redis"],
+        "color-mongodb": colors["mongodb"],
+        "color-memcached": colors["memcached"],
     },
 }
 
