@@ -3,27 +3,28 @@ Implementations of storage backends to be used with
 :class:`limits.strategies.RateLimiter` strategies
 """
 
+from __future__ import annotations
+
 import urllib
-from typing import Union, cast
 
-import limits
+import limits  # noqa
 
+from .._storage_scheme import SCHEMES
 from ..errors import ConfigurationError
-from .base import MovingWindowSupport, Storage
-from .gae_memcached import GAEMemcachedStorage
+from ..typing import TypeAlias, cast
+from .base import MovingWindowSupport, SlidingWindowCounterSupport, Storage
 from .memcached import MemcachedStorage
 from .memory import MemoryStorage
-from .mongodb import MongoDBStorage
+from .mongodb import MongoDBStorage, MongoDBStorageBase
 from .redis import RedisStorage
 from .redis_cluster import RedisClusterStorage
 from .redis_sentinel import RedisSentinelStorage
-from .registry import SCHEMES
 
-StorageTypes = Union[Storage, "limits.aio.storage.Storage"]
+StorageTypes: TypeAlias = "Storage | limits.aio.storage.Storage"
 
 
 def storage_from_string(
-    storage_string: str, **options: Union[float, str, bool]
+    storage_string: str, **options: float | str | bool
 ) -> StorageTypes:
     """
     Factory function to get an instance of the storage class based
@@ -32,9 +33,9 @@ def storage_from_string(
 
         from limits.storage import storage_from_string
 
-        memory = from_string("memory://")
-        memcached = from_string("memcached://localhost:11211")
-        redis = from_string("redis://localhost:6379")
+        memory = storage_from_string("memory://")
+        memcached = storage_from_string("memcached://localhost:11211")
+        redis = storage_from_string("redis://localhost:6379")
 
     The same function can be used to construct the :ref:`storage:async storage`
     variants, for example::
@@ -43,7 +44,7 @@ def storage_from_string(
 
         memory = storage_from_string("async+memory://")
         memcached = storage_from_string("async+memcached://localhost:11211")
-        redis = storage_from_string("asycn+redis://localhost:6379")
+        redis = storage_from_string("async+redis://localhost:6379")
 
     :param storage_string: a string of the form ``scheme://host:port``.
      More details about supported storage schemes can be found at
@@ -59,19 +60,21 @@ def storage_from_string(
     scheme = urllib.parse.urlparse(storage_string).scheme
 
     if scheme not in SCHEMES:
-        raise ConfigurationError("unknown storage scheme : %s" % storage_string)
+        raise ConfigurationError(f"unknown storage scheme : {storage_string}")
+
     return cast(StorageTypes, SCHEMES[scheme](storage_string, **options))
 
 
 __all__ = [
-    "storage_from_string",
-    "Storage",
-    "MovingWindowSupport",
+    "MemcachedStorage",
     "MemoryStorage",
     "MongoDBStorage",
-    "RedisStorage",
+    "MongoDBStorageBase",
+    "MovingWindowSupport",
     "RedisClusterStorage",
     "RedisSentinelStorage",
-    "MemcachedStorage",
-    "GAEMemcachedStorage",
+    "RedisStorage",
+    "SlidingWindowCounterSupport",
+    "Storage",
+    "storage_from_string",
 ]
